use sea_orm_migration::prelude::*;
use crate::m20230322_110525_create_post::Post;
use crate::m20230322_174812_create_tag::Tag;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(PostTag::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(PostTag::Id)
                            .big_integer()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(PostTag::TagId).big_integer().not_null())
                    .col(ColumnDef::new(PostTag::PostId).big_integer().not_null())
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-posttag-post_id")
                            .from(PostTag::Table, PostTag::PostId)
                            .to(Post::Table, Post::Id)
                    )
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-posttag-tag_id")
                            .from(PostTag::Table, PostTag::TagId)
                            .to(Tag::Table, Tag::Id)
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(PostTag::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
enum PostTag {
    Table,
    Id,
    PostId,
    TagId
}
