use sea_orm_migration::prelude::*;
use crate::m20230322_110525_create_post::Post;
use crate::m20230324_222553_create_file::File;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .alter_table(
                Table::alter()
                    .table(Post::Table)
                    .add_column(
                        ColumnDef::new(Alias::new("file"))
                            .big_integer()
                            .not_null()
                    )
                    .add_column(
                        ColumnDef::new(Alias::new("thumbnail"))
                            .big_integer()
                            .not_null()
                    )
                    .add_foreign_key(
                        TableForeignKey::new()
                            .name("fk-post_file-file_id")
                            .from_tbl(Post::Table)
                            .from_col(Alias::new("file"))
                            .to_tbl(File::Table)
                            .to_col(File::Id)
                            .on_delete(ForeignKeyAction::Cascade)
                            .on_update(ForeignKeyAction::Cascade)
                    )
                    .add_foreign_key(
                        TableForeignKey::new()
                            .name("fk-post_file-thumbnail_id")
                            .from_tbl(Post::Table)
                            .from_col(Alias::new("thumbnail"))
                            .to_tbl(File::Table)
                            .to_col(File::Id)
                            .on_delete(ForeignKeyAction::Cascade)
                            .on_update(ForeignKeyAction::Cascade)
                    )
                    .to_owned()
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .alter_table(
                Table::alter()
                    .table(Post::Table)
                    .drop_foreign_key(Alias::new("fk-post_file-file_id"))
                    .drop_foreign_key(Alias::new("fk-post_file-thumbnail_id"))
                    .drop_column(Alias::new("file"))
                    .drop_column(Alias::new("thumbnail"))
                    .to_owned()
            )
            .await
    }
}
