use askama::Template;
use axum::extract::State;
use sea_orm::{EntityTrait, PaginatorTrait};
use crate::AppState;
use crate::options::{Opt, Options};
use crate::entities::{prelude::*, *};

#[derive(Template)]
#[template(path = "index.html")]
pub struct IndexTemplate {
    site_name: String,
    url: String,
    asset_endpoint: String,
    posts_count: u64
}

pub async fn index(State(state): State<AppState>) -> IndexTemplate {
    let options = Options::get();

    let posts_count: u64 = post::Entity::find()
        .count(&state.conn)
        .await
        .expect("Failed to get count of posts!");

    IndexTemplate {
        site_name: options.name,
        url: options.url,
        asset_endpoint: options.asset_endpoint,
        posts_count,
    }
}
